
from __future__ import print_function
import sys
import numpy as np

def represent(obj):
    if isinstance(obj, np.ndarray):
        return "ndarray {0} [{1}]".format(obj.shape, obj.dtype)
    elif isinstance(obj, str):
        return "string ({0})".format(len(obj))
    else:
        lines = repr(obj).split("\n")
        if len(lines) > 5:
            lines = lines[:5] + ["..."]
        return "\n".join(lines)

def summarize(filename):
    s = ""
    try:
        data = np.load(filename)
    except IOError:
        data = None

    status = ''
    if data is None:
        return None#status = 'FILE NOT FOUND!'

    s += "-> {0} {1}\n".format(filename, status)
    
    if isinstance(data, np.lib.npyio.NpzFile):
        N = max(map(lambda x: len(x), data.keys()))
        indent = 3
        for k in data.keys():
            x = represent(data[k])
            x = x.replace('\n', '\n'+' '*(N+2 + indent))
            s += " "*indent + "{0} : {1}\n".format(k.rjust(N), x)
    else:
        indent = 3
        x = represent(data)
        x = x.replace('\n', '\n'+' '*(indent))
        s += " "*indent + x

    # Remove the last newline
    if s[-1] == '\n':
        s = s[:-1]
    return s





from __future__ import print_function
import sys
import nplook
import glob
from optparse import OptionParser

def main():
    examples = []
    examples.append(("data.npy", "summarizes the ndarray in data.npy"))
    examples.append(("data.npz", "summarizes the dictionary in data.npz"))
    examples.append(("*.npz", "summarizes all npz files in the directory"))
    examples.append(("", "summarizes all files in the directory"))

    ex_str = "\n".join(["  %prog {0:<18}{1}".format(tup[0], tup[1]) for tup in examples])

    usage = "Usage: %prog [options] <file> [<file> ...]\n\nExamples:\n{0}".format(ex_str)
    parser = OptionParser(usage=usage, version="%prog {0}".format(nplook.__version__))

    (options, args) = parser.parse_args()
    
    if args:
        filenames = args
    else:
        filenames = glob.glob("*")

    i = 0
    for filename in filenames:
        summary = nplook.summarize(filename)
        if summary: 
            if i != 0: print()
            print(summary)
            i += 1

    if i == 0:
        print("No files that can be summarized matched your query")



#!/usr/bin/env python

from __future__ import absolute_import
from distutils.core import setup

# Write this to
version = "0.1.1"

setup(name='nplook',
    version=version,
    author="Gustav Larsson",
    author_email="gustav.m.larsson@gmail.com",
    url="https://github.com/gustavla/nplook",
    description="Command-line tool that peeks into numpy npy or npz files and summarizes their contents",
    install_requires=['PIL'],
#    long_description="Tool for evaluating and analysing eye movement classification algorithms."
    packages=['nplook'],
    scripts=['scripts/nplook'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
    ],
)
